@@ -89,7 +89,8 @@ void KScreenDaemon::init()
     KActionCollection *coll = new KActionCollection(this);
     QAction* action = coll->addAction(QStringLiteral("display"));
     action->setText(i18n("Switch Display" ));
-    KGlobalAccel::self()->setGlobalShortcut(action, Qt::Key_Display);
+    QList<QKeySequence> switchDisplayShortcuts({Qt::Key_Display, Qt::MetaModifier + Qt::Key_P});
+    KGlobalAccel::self()->setGlobalShortcut(action, switchDisplayShortcuts);
     connect(action, &QAction::triggered, [&](bool) { displayButton(); });
 
     new KScreenAdaptor(this);
